@@ -188,21 +188,20 @@ if __name__ == '__main__':
     tself.jc = "jc"
 
     # declare a test
-    with test("test must_equal"):
+    with test(object.must_equal):
         tself.jc.must_equal('jc')
         None.must_equal(None)
 
-
-    with test("test must_true"):
+    with test(object.must_true):
         True.must_true()
         False.must_true()
 
-    with test("test must_false"):
+    with test(object.must_false):
         True.must_false()
         False.must_false()
 
     # using a funcation to test equal.
-    with test("test must_equal_with_func"):
+    with test("object.must_equal_with_func"):
         (1).must_equal(1, key=operator.eq)
         (1).must_equal(2, key=operator.eq)
 
